@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Mercurial::Push;
-{
-  $Dist::Zilla::Plugin::Mercurial::Push::VERSION = '0.02';
+BEGIN {
+  $Dist::Zilla::Plugin::Mercurial::Push::VERSION = '0.03';
 }
 
 use strict;
@@ -25,7 +25,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Push the current Mercurial branch
 
-__END__
+
 
 =pod
 
@@ -35,7 +35,7 @@ Dist::Zilla::Plugin::Mercurial::Push - Push the current Mercurial branch
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -51,7 +51,7 @@ Once the release is done, this plugin will push current Mercurial branch.
 
 =head1 AUTHOR
 
-Shlomi Fish <shlomif@cpan.org>
+  Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -61,3 +61,7 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
